==> ruby-1.6.6-i386-msdosdjgpp.tar.gz: usr/local/lib/ruby/1.6/i386-msdosdjgpp/rbconfig.rb <==

module Config

  RUBY_VERSION == "1.6.6" or
    raise "ruby lib version (1.6.6) doesn't match executable version (#{RUBY_VERSION})"

# This file was created by configrb when ruby was built. Any changes
# made to this file will be lost the next time ruby is built.
  DESTDIR = '' if not defined? DESTDIR
  CONFIG = {}
  TOPDIR = File.dirname(__FILE__).sub!(%r'/lib/ruby/1\.6/i386\-msdosdjgpp\Z', '')
  CONFIG["srcdir"] = "/pub/ruby/16/dist/ruby-1.6.6"
  CONFIG["prefix"] = (TOPDIR || DESTDIR + "/usr/local")
  CONFIG["ruby_install_name"] = "ruby"
  CONFIG["EXEEXT"] = ".exe"
  CONFIG["SHELL"] = "/bin/sh"
  CONFIG["CFLAGS"] = "-Os"
  CONFIG["CPPFLAGS"] = ""
  CONFIG["CXXFLAGS"] = ""
  CONFIG["FFLAGS"] = ""
  CONFIG["LDFLAGS"] = ""
  CONFIG["LIBS"] = "-lm"
  CONFIG["exec_prefix"] = "$(prefix)"
  CONFIG["bindir"] = "$(exec_prefix)/bin"
  CONFIG["sbindir"] = "$(exec_prefix)/sbin"
  CONFIG["libexecdir"] = "$(exec_prefix)/libexec"
  CONFIG["datadir"] = "$(prefix)/share"
  CONFIG["sysconfdir"] = "$(prefix)/etc"
  CONFIG["sharedstatedir"] = "$(prefix)/com"
  CONFIG["localstatedir"] = "$(prefix)/var"
  CONFIG["libdir"] = "$(exec_prefix)/lib"
  CONFIG["includedir"] = "$(prefix)/include"
  CONFIG["oldincludedir"] = "/usr/include"
  CONFIG["infodir"] = "$(prefix)/info"
  CONFIG["mandir"] = "$(prefix)/man"
  CONFIG["MAJOR"] = "1"
  CONFIG["MINOR"] = "6"
  CONFIG["TEENY"] = "6"
  CONFIG["host"] = "i586-pc-msdosdjgpp"
  CONFIG["host_alias"] = "i586-pc-msdosdjgpp"
  CONFIG["host_cpu"] = "i586"
  CONFIG["host_vendor"] = "pc"
  CONFIG["host_os"] = "msdosdjgpp"
  CONFIG["target"] = "i386-pc-msdosdjgpp"
  CONFIG["target_alias"] = "i386-msdosdjgpp"
  CONFIG["target_cpu"] = "i386"
  CONFIG["target_vendor"] = "pc"
  CONFIG["target_os"] = "msdosdjgpp"
  CONFIG["build"] = "i586-pc-linux-gnu"
  CONFIG["build_alias"] = "i586-pc-linux-gnu"
  CONFIG["build_cpu"] = "i586"
  CONFIG["build_vendor"] = "pc"
  CONFIG["build_os"] = "linux-gnu"
  CONFIG["CC"] = "gcc"
  CONFIG["CPP"] = "gcc -E"
  CONFIG["YACC"] = "bison -y"
  CONFIG["RANLIB"] = "ranlib"
  CONFIG["AR"] = "ar"
  CONFIG["NM"] = ""
  CONFIG["DLLWRAP"] = ""
  CONFIG["AS"] = ""
  CONFIG["DLLTOOL"] = ""
  CONFIG["WINDRES"] = ""
  CONFIG["LN_S"] = "ln -s"
  CONFIG["SET_MAKE"] = ""
  CONFIG["OBJEXT"] = "o"
  CONFIG["LIBOBJS"] = "crypt.o flock.o vsnprintf.o strtod.o"
  CONFIG["ALLOCA"] = ""
  CONFIG["XLDFLAGS"] = ""
  CONFIG["DLDFLAGS"] = ""
  CONFIG["STATIC"] = ""
  CONFIG["CCDLFLAGS"] = "-fPIC"
  CONFIG["LDSHARED"] = "ld"
  CONFIG["DLEXT"] = "so"
  CONFIG["DLEXT2"] = ""
  CONFIG["STRIP"] = "strip"
  CONFIG["EXTSTATIC"] = ""
  CONFIG["setup"] = "Setup.dj"
  CONFIG["MINIRUBY"] = "ruby -I/pub/ruby/16/dist/ruby-1.6.6/dobj -rfake"
  CONFIG["PREP"] = "fake.rb"
  CONFIG["LIBRUBY_LDSHARED"] = "ld"
  CONFIG["LIBRUBY_DLDFLAGS"] = ""
  CONFIG["RUBY_INSTALL_NAME"] = "ruby"
  CONFIG["RUBY_SO_NAME"] = ""
  CONFIG["LIBRUBY_A"] = "lib$(RUBY_INSTALL_NAME).a"
  CONFIG["LIBRUBY_SO"] = "lib$(RUBY_INSTALL_NAME).so.$(MAJOR).$(MINOR).$(TEENY)"
  CONFIG["LIBRUBY_ALIASES"] = "lib$(RUBY_INSTALL_NAME).so"
  CONFIG["LIBRUBY"] = "$(LIBRUBY_A)"
  CONFIG["LIBRUBYARG"] = "$(LIBRUBY_A)"
  CONFIG["SOLIBS"] = ""
  CONFIG["DLDLIBS"] = "-lc"
  CONFIG["ENABLE_SHARED"] = "no"
  CONFIG["MAINLIBS"] = ""
  CONFIG["arch"] = "i386-msdosdjgpp"
  CONFIG["sitedir"] = "$(prefix)/lib/ruby/site_ruby"
  CONFIG["configure_args"] = "--srcdir=.. --target=i386-msdosdjgpp --host=i586-pc-msdosdjgpp --build=i586-pc-linux-gnu --cache=../../config.cache-djgpp"
  CONFIG["ruby_version"] = "$(MAJOR).$(MINOR)"
  CONFIG["rubylibdir"] = "$(libdir)/ruby/$(ruby_version)"
  CONFIG["archdir"] = "$(rubylibdir)/$(arch)"
  CONFIG["sitelibdir"] = "$(sitedir)/$(ruby_version)"
  CONFIG["sitearchdir"] = "$(sitelibdir)/$(arch)"
  CONFIG["compile_dir"] = "/pub/ruby/16/dist/ruby-1.6.6/dobj"
  MAKEFILE_CONFIG = {}
  CONFIG.each{|k,v| MAKEFILE_CONFIG[k] = v.dup}
  def Config::expand(val)
    val.gsub!(/\$\(([^()]+)\)/) do |var|
      key = $1
      if CONFIG.key? key
        Config::expand(CONFIG[key])
      else
	var
      end
    end
    val
  end
  CONFIG.each_value do |val|
    Config::expand(val)
  end
end

==> ruby-1.6.8-1-i386-msdosdjgpp.tar.gz: usr/local/lib/ruby/1.6/i386-msdosdjgpp/rbconfig.rb <==

# This file was created by mkconfig.rb when ruby was built.  Any
# changes made to this file will be lost the next time ruby is built.

module Config
  RUBY_VERSION == "1.6.8" or
    raise "ruby lib version (1.6.8) doesn't match executable version (#{RUBY_VERSION})"

  DESTDIR = '' if not defined? DESTDIR
  CONFIG = {}
  TOPDIR = File.dirname(__FILE__).sub!(%r'/lib/ruby/1\.6/i386\-msdosdjgpp\Z', '')
  CONFIG["srcdir"] = "/pub/ruby/16/dist/ruby-1.6.8/ruby16"
  CONFIG["prefix"] = (TOPDIR || DESTDIR + "/usr/local")
  CONFIG["ruby_install_name"] = "ruby"
  CONFIG["EXEEXT"] = ".exe"
  CONFIG["SHELL"] = "/bin/sh"
  CONFIG["CFLAGS"] = "-Os"
  CONFIG["CPPFLAGS"] = ""
  CONFIG["CXXFLAGS"] = ""
  CONFIG["FFLAGS"] = ""
  CONFIG["LDFLAGS"] = ""
  CONFIG["LIBS"] = "-lm"
  CONFIG["exec_prefix"] = "$(prefix)"
  CONFIG["bindir"] = "$(exec_prefix)/bin"
  CONFIG["sbindir"] = "$(exec_prefix)/sbin"
  CONFIG["libexecdir"] = "$(exec_prefix)/libexec"
  CONFIG["datadir"] = "$(prefix)/share"
  CONFIG["sysconfdir"] = "$(prefix)/etc"
  CONFIG["sharedstatedir"] = "$(prefix)/com"
  CONFIG["localstatedir"] = "$(prefix)/var"
  CONFIG["libdir"] = "/usr/local/i586-pc-msdosdjgpp/lib"
  CONFIG["includedir"] = "/usr/local/i586-pc-msdosdjgpp/include"
  CONFIG["oldincludedir"] = "/usr/include"
  CONFIG["infodir"] = "$(prefix)/info"
  CONFIG["mandir"] = "$(prefix)/man"
  CONFIG["MAJOR"] = "1"
  CONFIG["MINOR"] = "6"
  CONFIG["TEENY"] = "8"
  CONFIG["host"] = "i586-pc-msdosdjgpp"
  CONFIG["host_alias"] = "i586-pc-msdosdjgpp"
  CONFIG["host_cpu"] = "i586"
  CONFIG["host_vendor"] = "pc"
  CONFIG["host_os"] = "msdosdjgpp"
  CONFIG["target"] = "i386-pc-msdosdjgpp"
  CONFIG["target_alias"] = "i386-msdosdjgpp"
  CONFIG["target_cpu"] = "i386"
  CONFIG["target_vendor"] = "pc"
  CONFIG["target_os"] = "msdosdjgpp"
  CONFIG["build"] = "i586-pc-linux-gnu"
  CONFIG["build_alias"] = "i586-pc-linux-gnu"
  CONFIG["build_cpu"] = "i586"
  CONFIG["build_vendor"] = "pc"
  CONFIG["build_os"] = "linux-gnu"
  CONFIG["CC"] = "gcc"
  CONFIG["CPP"] = "gcc -E"
  CONFIG["GNU_LD"] = "yes"
  CONFIG["CPPOUTFILE"] = ""
  CONFIG["OUTFLAG"] = "-o"
  CONFIG["YACC"] = "bison -y"
  CONFIG["RANLIB"] = "ranlib"
  CONFIG["AR"] = "ar"
  CONFIG["NM"] = ""
  CONFIG["DLLWRAP"] = ""
  CONFIG["AS"] = ""
  CONFIG["DLLTOOL"] = ""
  CONFIG["WINDRES"] = ""
  CONFIG["LN_S"] = "ln -s"
  CONFIG["SET_MAKE"] = ""
  CONFIG["OBJEXT"] = "o"
  CONFIG["LIBOBJS"] = "crypt.o flock.o vsnprintf.o"
  CONFIG["ALLOCA"] = ""
  CONFIG["XLDFLAGS"] = ""
  CONFIG["DLDFLAGS"] = ""
  CONFIG["STATIC"] = ""
  CONFIG["CCDLFLAGS"] = "-fPIC"
  CONFIG["LDSHARED"] = "ld"
  CONFIG["DLEXT"] = "so"
  CONFIG["DLEXT2"] = ""
  CONFIG["STRIP"] = "strip"
  CONFIG["EXTSTATIC"] = ""
  CONFIG["setup"] = "Setup.dj"
  CONFIG["MINIRUBY"] = "ruby -I/pub/ruby/16/dist/ruby-1.6.8/d.obj -rfake"
  CONFIG["PREP"] = "fake.rb"
  CONFIG["LIBRUBY_LDSHARED"] = "ld"
  CONFIG["LIBRUBY_DLDFLAGS"] = ""
  CONFIG["RUBY_INSTALL_NAME"] = "ruby"
  CONFIG["RUBY_SO_NAME"] = ""
  CONFIG["LIBRUBY_A"] = "lib$(RUBY_INSTALL_NAME).a"
  CONFIG["LIBRUBY_SO"] = "lib$(RUBY_INSTALL_NAME).so.$(MAJOR).$(MINOR).$(TEENY)"
  CONFIG["LIBRUBY_ALIASES"] = "lib$(RUBY_INSTALL_NAME).so"
  CONFIG["LIBRUBY"] = "$(LIBRUBY_A)"
  CONFIG["LIBRUBYARG"] = "$(LIBRUBY_A)"
  CONFIG["SOLIBS"] = ""
  CONFIG["DLDLIBS"] = "-lc"
  CONFIG["ENABLE_SHARED"] = "no"
  CONFIG["MAINLIBS"] = ""
  CONFIG["arch"] = "i386-msdosdjgpp"
  CONFIG["sitedir"] = "$(prefix)/lib/ruby/site_ruby"
  CONFIG["configure_args"] = "--includedir=/usr/local/i586-pc-msdosdjgpp/include --libdir=/usr/local/i586-pc-msdosdjgpp/lib --target=i386-msdosdjgpp --host=i586-pc-msdosdjgpp --build=i586-pc-linux-gnu --with-opt-dir=/usr/local/i586-pc-msdosdjgpp --cache=./config.cache"
  CONFIG["ruby_version"] = "$(MAJOR).$(MINOR)"
  CONFIG["rubylibdir"] = "$(libdir)/ruby/$(ruby_version)"
  CONFIG["archdir"] = "$(rubylibdir)/$(arch)"
  CONFIG["sitelibdir"] = "$(sitedir)/$(ruby_version)"
  CONFIG["sitearchdir"] = "$(sitelibdir)/$(arch)"
  CONFIG["compile_dir"] = "/pub/ruby/16/dist/ruby-1.6.8/d.obj"
  MAKEFILE_CONFIG = {}
  CONFIG.each{|k,v| MAKEFILE_CONFIG[k] = v.dup}
  def Config::expand(val)
    val.gsub!(/\$\(([^()]+)\)/) do |var|
      key = $1
      if CONFIG.key? key
        Config::expand(CONFIG[key])
      else
	var
      end
    end
    val
  end
  CONFIG.each_value do |val|
    Config::expand(val)
  end
end
